==> TopdataTopFinderProSW6-v2.0.1.zip: TopdataTopFinderProSW6/src/Controller/TopFinderBrandController.php <==
<?php

declare(strict_types=1);

namespace Topdata\TopdataTopFinderProSW6\Controller;

use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Shopware\Storefront\Controller\StorefrontController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\Routing\Annotation\Route;
use Topdata\TopdataTopFinderProSW6\Constants\CookieKeyNameConstants;
use Topdata\TopdataTopFinderProSW6\Constants\TopfinderPluginConstants;
use Topdata\TopdataTopFinderProSW6\Service\TopdataDeviceDataService;
use Topdata\TopdataTopFinderProSW6\Service\HelperService;
use Topdata\TopdataTopFinderProSW6\Service\SettingsService;
use Topdata\TopdataTopFinderProSW6\Storefront\PageLoader\OneBrandLetterPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\PageLoader\Topfinder\MyList\BrandListPageLoader;
use Topdata\TopdataTopFinderProSW6\Util\ControllerUtil;

/**
 * 11/2024 created (extracted from TopFinderController)
 * @\Symfony\Component\Routing\Annotation\Route(defaults={"_routeScope"={"storefront"}})
 */
class TopFinderBrandController extends StorefrontController
{
    /**
     * @readonly
     */
    private EntityRepository $topdataSeriesRepository;
    /**
     * @readonly
     */
    private EntityRepository $topdataDeviceTypeRepository;
    /**
     * @readonly
     */
    private SettingsService $settingsService;
    /**
     * @readonly
     */
    private BrandListPageLoader $brandListPageLoader;
    /**
     * @readonly
     */
    private OneBrandLetterPageLoader $oneBrandLetterPageLoader;
    /**
     * @readonly
     */
    private TopdataDeviceDataService $deviceDataService;
    public function __construct(EntityRepository         $topdataSeriesRepository, EntityRepository         $topdataDeviceTypeRepository, SettingsService          $settingsService, BrandListPageLoader      $brandListPageLoader, OneBrandLetterPageLoader $oneBrandLetterPageLoader, TopdataDeviceDataService $deviceDataService)
    {
        $this->topdataSeriesRepository = $topdataSeriesRepository;
        $this->topdataDeviceTypeRepository = $topdataDeviceTypeRepository;
        $this->settingsService = $settingsService;
        $this->brandListPageLoader = $brandListPageLoader;
        $this->oneBrandLetterPageLoader = $oneBrandLetterPageLoader;
        $this->deviceDataService = $deviceDataService;
    }
    /**
     * renders "one-brand-letter.html.twig"
     *
     * Handles the request to list a specific brand
     *
     * This method loads the brand listing page based on the provided request and context,
     * and renders the corresponding Twig template. It also sets the brand code and retrieves
     * series and types if configured to do so.
     *
     * @param Request $request The HTTP request object.
     * @param SalesChannelContext $salesChanelContext The sales channel context.
     * @return Response The HTTP response object containing the rendered brand listing page.
     * @throws BadRequestHttpException If the brand code is invalid.
     * @\Symfony\Component\Routing\Annotation\Route(path="/top-finder/brand/{brandCode}", name="frontend.top-finder.show-brand", methods={"GET"})
     */
    public function showBrandAction(string $brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->load(
            $request,
            $salesChanelContext,
            $brandCode
        );
        $finderStruct = $page->getHeader()->getExtension('finder');
        if ($finderStruct !== null) {
            $finderStruct->set('brandCode', $page->brand['code']);

            if ($this->settingsService->getConfig('showSeries')) {
                $series = ControllerUtil::getEntityCollection(
                    $this->topdataSeriesRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->brand['id'],
                    ],
                    'label'
                );
                $finderStruct->set('series', $series);
            }

            if ($this->settingsService->getConfig('showTypes')) {
                $types = ControllerUtil::getEntityCollection(
                    $this->topdataDeviceTypeRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->brand['id'],
                    ],
                    'label'
                );
                $finderStruct->set('types', $types);
            }

            $devicesArray = $this->deviceDataService->getFilteredDevices($page->brand['id'], 0, 0, false);
            $finderStruct->set('devices', $devicesArray);
        }
        return $this->renderStorefront(
            '@TopdataTopFinderProSW6/storefront/page/topfinder/one-brand-letter.html.twig',
            ['page' => $page]
        );
    }
    /**
     * renders "list.html.twig"
     *
     * Handles the request to list a specific brand.
     *
     * This method loads the brand listing page based on the provided request and context,
     * and renders the corresponding Twig template. It also sets the brand code and retrieves
     * series and types if configured to do so.
     *
     * @param Request $request The HTTP request object.
     * @param SalesChannelContext $salesChanelContext The sales channel context.
     * @return Response The HTTP response object containing the rendered brand listing page.
     * @throws BadRequestHttpException If the brand code is invalid.
     * @\Symfony\Component\Routing\Annotation\Route("/top-finder/brandq/{code}", name="frontend.top-finder.brandq", methods={"GET"})
     */
    public function listBrandQ(Request $request, SalesChannelContext $salesChanelContext): Response
    {
        $brandCode = $request->get('code');
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->brandListPageLoader->load($request, $salesChanelContext);
        $finderStruct = $page->getHeader()->getExtension('finder');
        if ($finderStruct !== null) {
            $finderStruct->set('brandCode', $page->model->getCode());

            if ($this->settingsService->getConfig('showSeries')) {
                $series = ControllerUtil::getEntityCollection(
                    $this->topdataSeriesRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->model->getId(),
                    ],
                    'label'
                );
                $finderStruct->set('series', $series);
            }

            if ($this->settingsService->getConfig('showTypes')) {
                $types = ControllerUtil::getEntityCollection(
                    $this->topdataDeviceTypeRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->model->getId(),
                    ],
                    'label'
                );
                $finderStruct->set('types', $types);
            }

            $devicesArray = $this->deviceDataService->getFilteredDevices($page->model->getId(), 0, 0, false);
            //$devicesArray = $this->getDevicesArray($page->model->getId(), -1, -1, false);
            $finderStruct->set('devices', $devicesArray);
        }
        return $this->renderStorefront('@TopdataTopFinderProSW6/storefront/page/topfinder/list.html.twig', ['page' => $page]);
    }
    /**
     * @\Symfony\Component\Routing\Annotation\Route("/top-finder/letter-brand/{brandCode}", name="frontend.top-finder.letter-brand", methods={"GET"})
     */
    public function listLetterBrand($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->load($request, $salesChanelContext, $brandCode);
        return $this->renderStorefront('@TopdataTopFinderProSW6/storefront/page/topfinder/one-brand-letter.html.twig', ['page' => $page]);
    }
    /**
     * @\Symfony\Component\Routing\Annotation\Route(path="/top-finder/popup-brand/{brandCode}", name="frontend.top-finder.popup_brand", defaults={"XmlHttpRequest": true}, methods={"GET"})
     */
    public function listPopupBrand($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->loadJson(
            $request,
            $salesChanelContext,
            $brandCode,
            'all'
        );
        $offset = $request->get('offset');
        $defaultOffset = TopfinderPluginConstants::POPUP_DEVICES_PRELOAD_LENGTH;
        if ($offset) {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/_listed-devices.html.twig',
                    ['page' => $page, 'offset' => $offset]
                );
        } else {
            $listMode = $request->cookies->get(CookieKeyNameConstants::POPUP_DEVICELIST_MODE);
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/brand-devices.html.twig',
                    [
                        'page'     => $page,
                        'mode'     => 'all',
                        'listMode' => $listMode,
                        'offset'   => $defaultOffset,
                    ]
                );
            $response->headers->set('returnPath', ControllerUtil::getReturnPath($request));
            $response->headers->set('loadOffset', (string)$defaultOffset);
        }
        //        $response = new JsonResponse($result);
        $response->headers->set('X-Robots-Tag', 'noindex, nofollow');
        return $response;
    }
    /**
     * @\Symfony\Component\Routing\Annotation\Route(path="/top-finder/popup-brand-series/{brandCode}", name="frontend.top-finder.popup_brand_series", defaults={"XmlHttpRequest": true}, methods={"GET"})
     */
    public function listPopupBrandSeries($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->loadJson(
            $request,
            $salesChanelContext,
            $brandCode,
            'series'
        );
        $listMode = $request->cookies->get(CookieKeyNameConstants::POPUP_DEVICELIST_MODE);
        $offset = $request->get('offset');
        $defaultOffset = TopfinderPluginConstants::POPUP_DEVICES_PRELOAD_LENGTH;
        if ($offset) {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/_listed-series-devices.html.twig',
                    ['page' => $page, 'offset' => $offset, 'hideMenuSeries' => true]
                );
        } else {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/brand-devices.html.twig',
                    [
                        'page'           => $page,
                        'mode'           => 'series',
                        'listMode'       => $listMode,
                        'offset'         => $defaultOffset,
                        'hideMenuSeries' => true,
                    ]
                );
            $response->headers->set('returnPath', ControllerUtil::getReturnPath($request));
            $response->headers->set('loadOffset', (string)$defaultOffset);
        }
        $response->headers->set('X-Robots-Tag', 'noindex, nofollow');
        return $response;
    }
    /**
     * @\Symfony\Component\Routing\Annotation\Route("/top-finder/popup-brand-types/{brandCode}", name="frontend.top-finder.popup_brand_types", methods={"GET"}, defaults={"XmlHttpRequest": true})
     */
    public function listPopupBrandTypes($brandCode, Request $request, SalesChannelContext $salesChanelContext)
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->loadJson(
            $request,
            $salesChanelContext,
            $brandCode,
            'types'
        );
        $listMode = $request->cookies->get(CookieKeyNameConstants::POPUP_DEVICELIST_MODE);
        $offset = $request->get('offset');
        $defaultOffset = TopfinderPluginConstants::POPUP_DEVICES_PRELOAD_LENGTH;
        if ($offset) {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/_listed-types-devices.html.twig',
                    ['page' => $page, 'offset' => $offset]
                );
        } else {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/brand-devices.html.twig',
                    [
                        'page'     => $page,
                        'mode'     => 'types',
                        'listMode' => $listMode,
                        'offset'   => $defaultOffset,
                    ]
                );

            $response->headers->set('returnPath', ControllerUtil::getReturnPath($request));
            $response->headers->set('loadOffset', (string)$defaultOffset);
        }
        $response->headers->set('X-Robots-Tag', 'noindex, nofollow');
        return $response;
    }
}

==> TopdataTopFinderProSW6-v7.0.5.zip: TopdataTopFinderProSW6/src/Controller/TopFinderBrandController.php <==
<?php

declare(strict_types=1);

namespace Topdata\TopdataTopFinderProSW6\Controller;

use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Shopware\Storefront\Controller\StorefrontController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\Routing\Annotation\Route;
use Topdata\TopdataTopFinderProSW6\Constants\CookieKeyNameConstants;
use Topdata\TopdataTopFinderProSW6\Service\DeviceToCustomerService;
use Topdata\TopdataTopFinderProSW6\Service\HelperService;
use Topdata\TopdataTopFinderProSW6\Service\SettingsService;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\BrandLetter\BrandLetterPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\Device\DevicePageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\ListProducts\ListProductsLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\OneBrandLetter\OneBrandLetterPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\PopupDeviceInfoWidgetPage\PopupDeviceInfoWidgetPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\PopupDeviceWidget\PopupDeviceWidgetLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\PopupFormWidget\PopupFormWidgetLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\Topfinder\DeviceListPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\Topfinder\DeviceSearchPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\Topfinder\DeviceSuggestPageLoader;
use Topdata\TopdataTopFinderProSW6\Storefront\Page\Topfinder\ListPageLoader;
use Topdata\TopdataTopFinderProSW6\Util\ControllerUtil;

/**
 * 11/2024 created (extracted from TopFinderController)
 */
#[Route(defaults: ['_routeScope' => ['storefront']])]
class TopFinderBrandController extends StorefrontController
{


    public function __construct(
        private readonly EntityRepository                $topdataSeriesRepository,
        private readonly EntityRepository                $topdataDeviceTypeRepository,
        private readonly SettingsService                 $settingsService,
        private readonly ListPageLoader                  $listPageLoader,
        private readonly OneBrandLetterPageLoader        $oneBrandLetterPageLoader,
        private readonly HelperService                   $helperService,
    )
    {
    }

    /**
     * renders "one-brand-letter.html.twig"
     *
     * Handles the request to list a specific brand
     *
     * This method loads the brand listing page based on the provided request and context,
     * and renders the corresponding Twig template. It also sets the brand code and retrieves
     * series and types if configured to do so.
     *
     * @param Request $request The HTTP request object.
     * @param SalesChannelContext $salesChanelContext The sales channel context.
     * @return Response The HTTP response object containing the rendered brand listing page.
     * @throws BadRequestHttpException If the brand code is invalid.
     */
    #[Route('/top-finder/brand/{brandCode}', name: 'frontend.top-finder.brand', methods: ['GET'])]
    public function listBrand($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->load(
            $request,
            $salesChanelContext,
            $brandCode
        );

        $finderStruct = $page->getHeader()->getExtension('finder');
        if ($finderStruct !== null) {
            $finderStruct->set('brandCode', $page->brand['code']);

            if ($this->settingsService->getConfig('showSeries')) {
                $series = \Topdata\TopdataTopFinderProSW6\Util\ControllerUtil::getEntityCollection(
                    $this->topdataSeriesRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->brand['id'],
                    ],
                    'label'
                );
                $finderStruct->set('series', $series);
            }

            if ($this->settingsService->getConfig('showTypes')) {
                $types = \Topdata\TopdataTopFinderProSW6\Util\ControllerUtil::getEntityCollection(
                    $this->topdataDeviceTypeRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->brand['id'],
                    ],
                    'label'
                );
                $finderStruct->set('types', $types);
            }

            $devicesArray = $this->helperService->getFilteredDevices($page->brand['id'], 0, 0, false);
            $finderStruct->set('devices', $devicesArray);
        }

        return $this->renderStorefront(
            '@TopdataTopFinderProSW6/storefront/page/topfinder/one-brand-letter.html.twig',
            ['page' => $page]
        );
    }

    /**
     * renders "list.html.twig"
     *
     * Handles the request to list a specific brand.
     *
     * This method loads the brand listing page based on the provided request and context,
     * and renders the corresponding Twig template. It also sets the brand code and retrieves
     * series and types if configured to do so.
     *
     * @param Request $request The HTTP request object.
     * @param SalesChannelContext $salesChanelContext The sales channel context.
     * @return Response The HTTP response object containing the rendered brand listing page.
     * @throws BadRequestHttpException If the brand code is invalid.
     */
    #[Route('/top-finder/brandq/{code}', name: 'frontend.top-finder.brandq', methods: ['GET'])]
    public function listBrandQ(Request $request, SalesChannelContext $salesChanelContext): Response
    {
        $brandCode = $request->get('code');
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->listPageLoader->loadPage($request, $salesChanelContext, ListPageLoader::TYPE_BRAND);

        $finderStruct = $page->getHeader()->getExtension('finder');
        if ($finderStruct !== null) {
            $finderStruct->set('brandCode', $page->model->getCode());

            if ($this->settingsService->getConfig('showSeries')) {
                $series = \Topdata\TopdataTopFinderProSW6\Util\ControllerUtil::getEntityCollection(
                    $this->topdataSeriesRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->model->getId(),
                    ],
                    'label'
                );
                $finderStruct->set('series', $series);
            }

            if ($this->settingsService->getConfig('showTypes')) {
                $types = \Topdata\TopdataTopFinderProSW6\Util\ControllerUtil::getEntityCollection(
                    $this->topdataDeviceTypeRepository,
                    [
                        'enabled' => true,
                        'brandId' => $page->model->getId(),
                    ],
                    'label'
                );
                $finderStruct->set('types', $types);
            }

            $devicesArray = $this->helperService->getFilteredDevices($page->model->getId(), 0, 0, false);
            //$devicesArray = $this->getDevicesArray($page->model->getId(), -1, -1, false);
            $finderStruct->set('devices', $devicesArray);
        }

        return $this->renderStorefront('@TopdataTopFinderProSW6/storefront/page/topfinder/list.html.twig', ['page' => $page]);
    }



    #[Route('/top-finder/letter-brand/{brandCode}', name: 'frontend.top-finder.letter-brand', methods: ['GET'])]
    public function listLetterBrand($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->load($request, $salesChanelContext, $brandCode);

        return $this->renderStorefront('@TopdataTopFinderProSW6/storefront/page/topfinder/one-brand-letter.html.twig', ['page' => $page]);
    }


    #[Route(
        path: '/top-finder/popup-brand/{brandCode}',
        name: 'frontend.top-finder.popup_brand',
        defaults: ['XmlHttpRequest' => true],
        methods: ['GET']
    )]
    public function listPopupBrand($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->loadJson(
            $request,
            $salesChanelContext,
            $brandCode,
            'all'
        );

        $offset = $request->get('offset');
        $defaultOffset = \Topdata\TopdataTopFinderProSW6\Constants\TopfinderPluginConstants::POPUP_DEVICES_PRELOAD_LENGTH;
        if ($offset) {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/_listed-devices.html.twig',
                    ['page' => $page, 'offset' => $offset]
                );
        } else {
            $listMode = $request->cookies->get(CookieKeyNameConstants::POPUP_DEVICELIST_MODE);
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/brand-devices.html.twig',
                    [
                        'page'     => $page,
                        'mode'     => 'all',
                        'listMode' => $listMode,
                        'offset'   => $defaultOffset,
                    ]
                );
            $response->headers->set('returnPath', ControllerUtil::getReturnPath($request));
            $response->headers->set('loadOffset', (string)$defaultOffset);
        }

        //        $response = new JsonResponse($result);
        $response->headers->set('X-Robots-Tag', 'noindex, nofollow');

        return $response;
    }




    #[Route(
        path: '/top-finder/popup-brand-series/{brandCode}',
        name: 'frontend.top-finder.popup_brand_series',
        defaults: ['XmlHttpRequest' => true],
        methods: ['GET'],
    )]
    public function listPopupBrandSeries($brandCode, Request $request, SalesChannelContext $salesChanelContext): Response
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->loadJson(
            $request,
            $salesChanelContext,
            $brandCode,
            'series'
        );

        $listMode = $request->cookies->get(CookieKeyNameConstants::POPUP_DEVICELIST_MODE);
        $offset = $request->get('offset');
        $defaultOffset = \Topdata\TopdataTopFinderProSW6\Constants\TopfinderPluginConstants::POPUP_DEVICES_PRELOAD_LENGTH;
        if ($offset) {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/_listed-series-devices.html.twig',
                    ['page' => $page, 'offset' => $offset, 'hideMenuSeries' => true]
                );
        } else {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/brand-devices.html.twig',
                    [
                        'page'           => $page,
                        'mode'           => 'series',
                        'listMode'       => $listMode,
                        'offset'         => $defaultOffset,
                        'hideMenuSeries' => true,
                    ]
                );
            $response->headers->set('returnPath', ControllerUtil::getReturnPath($request));
            $response->headers->set('loadOffset', (string)$defaultOffset);
        }

        $response->headers->set('X-Robots-Tag', 'noindex, nofollow');

        return $response;
    }


    #[Route('/top-finder/popup-brand-types/{brandCode}', name: 'frontend.top-finder.popup_brand_types', methods: ['GET'], defaults: ['XmlHttpRequest' => true])]
    public function listPopupBrandTypes($brandCode, Request $request, SalesChannelContext $salesChanelContext)
    {
        ControllerUtil::assertValidBrandcode($brandCode);
        $page = $this->oneBrandLetterPageLoader->loadJson(
            $request,
            $salesChanelContext,
            $brandCode,
            'types'
        );

        $listMode = $request->cookies->get(CookieKeyNameConstants::POPUP_DEVICELIST_MODE);
        $offset = $request->get('offset');
        $defaultOffset = \Topdata\TopdataTopFinderProSW6\Constants\TopfinderPluginConstants::POPUP_DEVICES_PRELOAD_LENGTH;
        if ($offset) {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/_listed-types-devices.html.twig',
                    ['page' => $page, 'offset' => $offset]
                );
        } else {
            $response = $this
                ->renderStorefront(
                    '@TopdataTopFinderProSW6/storefront/widget/popup-form/brand-devices.html.twig',
                    [
                        'page'     => $page,
                        'mode'     => 'types',
                        'listMode' => $listMode,
                        'offset'   => $defaultOffset,
                    ]
                );

            $response->headers->set('returnPath', ControllerUtil::getReturnPath($request));
            $response->headers->set('loadOffset', (string)$defaultOffset);
        }

        $response->headers->set('X-Robots-Tag', 'noindex, nofollow');

        return $response;
    }


}
